@@ -3,7 +3,8 @@
 ;; Copyright (C) 2013-2022  Free Software Foundation, Inc.
 
 ;; Author: Leo Liu <sdl.web@gmail.com>
-;; Version: 0.9.5
+;; Package-Version: 20260105.825
+;; Package-Revision: 3c0fbada8ca5
 ;; Package-Type: simple
 ;; Package-Requires: ((emacs "25") (cl-lib "0.5"))
 ;; Keywords: killing, convenience
@@ -74,29 +75,11 @@ string) for appending current selection to previous kill."
   :type '(repeat symbol)
   :group 'killing)
 
-(defcustom easy-kill-exit-hook nil
-  "A list of functions to be called when `easy-kill' exits.
-
-At the moment they are run, the current candidate is still accessible
-and `this-command' has the command that is to put an end to the
-easy-kill mode."
-  :type '(repeat function)
-  :group 'killing)
-
 (defcustom easy-mark-try-things '(url email uuid sexp)
   "A list of things for `easy-mark' to try."
   :type '(repeat symbol)
   :group 'killing)
 
-(defcustom easy-mark-exit-hook nil
-  "A list of functions to be called when `easy-mark' exits.
-
-At the moment they are run, the current candidate is still accessible
-and `this-command' has the command that is to put an end to the
-easy-mark mode."
-  :type '(repeat function)
-  :group 'killing)
-
 (defcustom easy-dup-try-things '(line)
   "A list of things for `easy-dup-before' and `easy-dup-after' to try."
   :type '(repeat symbol)
@@ -590,11 +573,8 @@ checked."
                           (command-remapping cmd nil (list map)))))
                (ignore
                 (easy-kill-destroy-candidate)
-                (if (easy-kill-get mark)
-                    (run-hooks 'easy-mark-exit-hook)
-                  (or (easy-kill-exit-p this-command)
-                      (easy-kill-save-candidate))
-                  (run-hooks 'easy-kill-exit-hook))))
+                (unless (or (easy-kill-get mark) (easy-kill-exit-p this-command))
+                  (easy-kill-save-candidate))))
          (error (message "%s:%s" this-command (error-message-string err))
                 nil))))))
 
